#!/usr/bin/python3
# Um simples inversor de URL escrito em Python3 e PyGObject
# Rafael Santos <rafael@sourcecode.net.br>

from gi.repository import Gtk, Gdk

class Inverter(object):
    def __init__(self):
        builder = Gtk.Builder()
        builder.add_from_file("inverter.glade")
        self.window = builder.get_object("window")
        self.window.show()
        self.url = builder.get_object("entry")
        self.about = builder.get_object("aboutdialog")
        builder.connect_signals({
                                "gtk_main_quit": Gtk.main_quit,
                                "on_entry_activate": self.invert_url,
                                "on_button_clicked": self.invert_url,
                                "on_copy_activate": self.copy_text,
                                "on_paste_activate": self.paste_text,
                                "on_delete_activate": self.delete_text,
                                "on_about_activate": self.about_window,
                                })
                                
    def invert_url(self, widget):
        text = self.url.get_text()
        text = text[::-1]
        self.url.set_text(text)
        
    def copy_text(self, widget):
        atom = Gdk.atom_intern("CLIPBOARD", True)
        clipboard = Gtk.Clipboard.get(atom)
        text = self.url.get_text()
        clipboard.set_text(text, -1)
        clipboard.store()
        
    def paste_text(self, widget):
        atom = Gdk.atom_intern("CLIPBOARD", True)
        clipboard = Gtk.Clipboard.get(atom)
        text = clipboard.wait_for_text()
        self.url.set_text(text)
        
    def delete_text(self, widget):
        self.url.set_text("")
        
    def about_window(self, widget):
        self.about.run()
        self.about.hide()
        
if __name__ == "__main__":
    app = Inverter()
    Gtk.main()
